Module: Glossync::MissingTranslationHandler

Defined in:
lib/glossync/missing_translation_handler.rb

Overview

Holds various missing translation handlers. Any object is a missing translation handler if it responds to the method handle with an arity of 4

Defined Under Namespace

Classes: Default, GoogleTranslate, Raiser